X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/45e6e6f8ab806b337dffeb3b52fec7eba3c845ef..d8eff331e23435d9d8d6483a40f6fd9997a13f87:/samples/html/about/about.cpp

diff --git a/samples/html/about/about.cpp b/samples/html/about/about.cpp
index 9613d9890f..9205f45996 100644
--- a/samples/html/about/about.cpp
+++ b/samples/html/about/about.cpp
@@ -1,6 +1,12 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        test.cpp
 // Purpose:     wxHtml testing example
 /////////////////////////////////////////////////////////////////////////////
 
 // For compilers that support precompilation, includes "wx/wx.h".
@@ -21,6 +27,11 @@
 #include "wx/wxhtml.h"
 #include "wx/statline.h"
 
+#ifndef __WXMSW__
+    #include "../../sample.xpm"
+#endif
+
+
 // ----------------------------------------------------------------------------
 // private classes
 // ----------------------------------------------------------------------------
@@ -109,6 +120,8 @@ bool MyApp::OnInit()
 MyFrame::MyFrame(const wxString& title)
        : wxFrame((wxFrame *)NULL, wxID_ANY, title)
 {
+    SetIcon(wxICON(sample));
+
     // create a menu bar
     wxMenu *menuFile = new wxMenu;
@@ -1,6 +1,12 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        test.cpp
-// Purpose:     wxHtml testing example
+// Name:        about.cpp
+// Purpose:     wxHtml sample: about dialog test
+// Author:      ?
+// Modified by:
+// Created:     ?
+// RCS-ID:      $Id$
+// Copyright:   (c) wxWidgets team
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 